@@ -84,14 +84,24 @@ class filelistwin(window.window):
             self.searchpositions = []
             self.searchstring = searchstring
             hub.notify(events.activatefilelist())
+        elif key == 1023:
+            if self.searchpositions:
+                self.items.selectbynr(self.searchpositions.pop())
+            self.searchpositions = []
+            self.searchstring = searchstring
+            hub.notify(events.activatefilelist())
         else:
             self.searchpositions.append(self.items.selected)
             self.items.selectbyregexp(searchstring)
+            # We explicitely issue a selectionchanged event because the
+            # selectbyregexp doesn't do this due to the focus being on the
+            # searchstring input window
+        hub.notify(events.selectionchanged(self.items.getselected()))
         self.update()
         
     def isclickonstring(self, y, x):
         """ check whether a click was on a string or not """
-        while x<self.ix+self.iw:
+        while x < self.ix+self.iw:
             if self.win.inch(y, x) & 0xFF!=32:
                 return 1
             x += 1
@@ -234,7 +244,7 @@ class filelistwin(window.window):
                         attr = self.colors.selected_song
                     else:
                         attr = self.colors.song
-                elif aitem.isartistoralbum():
+                elif aitem.isartist() or aitem.isalbum():
                     if i==self.items.selected and showselectionbar:
                         attr = self.colors.selected_artist_album
                     else:
