@@ -91,12 +91,13 @@ class iteminfowin(window.window):
             info = []
         l = info + empty*(4-len(info))
 
-        colsep = self.iw>45
+        colsep = self.iw > 45
 
         # calculate width of columns
         wc1 = max( len(l[0][0]), len(l[1][0]), len(l[2][0]), len(l[3][0])) + colsep
         wc3 = max( len(l[0][2]), len(l[1][2]), len(l[2][2])) + colsep
         wc4 = 5
+        wc4 = max( len(l[0][3]), len(l[1][3]), len(l[2][3]))
         wc2 = self.iw-wc1-wc3-wc4-1
 
         for lno in range(4):
@@ -104,11 +105,11 @@ class iteminfowin(window.window):
             self.addstr(l[lno][0].ljust(wc1)[:wc1], self.colors.description)
             self.addstr(l[lno][1].ljust(wc2)[:wc2], self.colors.content)
             self.addch(" ")
-            if lno!=3:
+            if lno != 3 or isinstance(aitem, item.diritem):
                 self.addstr(l[lno][2].ljust(wc3)[:wc3], self.colors.description)
                 self.addstr(l[lno][3].ljust(wc4)[:wc4], self.colors.content)
             else:
-                # special handling of last line
+                # special handling of last line for songs
                 wc3 = max(len(l[3][-2]), 5) + colsep
                 wc4 = max(len(l[3][-1]), 5)
                 
@@ -193,7 +194,7 @@ class iteminfowinlong(messagewin.messagewin):
             info = []
         l = info + empty*(4-len(info))
 
-        colsep = self.iw>45
+        colsep = self.iw > 45
 
         # calculate width of columns
         wc1 = 0
@@ -208,7 +209,7 @@ class iteminfowinlong(messagewin.messagewin):
         self.clear()
         for lno in range(len(info)):
             line = l[lno]
-            self.move(1+lno, self.ix)
+            self.move(self.iy+lno, self.ix)
             self.addstr(line[0].ljust(wc1)[:wc1], self.colors.description)
             self.addstr(line[1].ljust(wc2)[:wc2], self.colors.content)
             self.addch(" ")
