@@ -99,14 +99,15 @@ for o, a in opts:
 if server is not None and unixsocketfile is not None:
     print "Error: cannot connect both via network and unix sockets"
     sys.exit(2)
-if server is None and unixsocketfile is None:
+if server is None:
+    if unixsocketfile is None:
         unixsocketfile =  os.path.expanduser("~/.pytone/pytonectl")
+    networklocation = unixsocketfile
+else:
+    networklocation = server, port
 
 try:
-    if server is not None:
-        channel = network.tcpclientchannel(server, port)
-    else:
-        channel = network.unixclientchannel(unixsocketfile)
+    channel = network.clientchannel(networklocation)
 except Exception, e:
     print "Error: cannot connect to PyTone server: %s" % e
     sys.exit(2)
