@@ -62,13 +62,18 @@ class dbrequestsongs(dbrequest):
     # standard song wrapper function, wrapping a dbitem.song instance in a item.song instance
     def _songwrapper(song, songdbid):
         return item.song(songdbid, song)
-    
-    def __init__(self, songdbid, random=False, sort=False, wrapperfunc=_songwrapper):
+
+    def __init__(self, songdbid, random=False, sort=False, wrapperfunc=_songwrapper, filters=None):
         self.songdbid = songdbid
         self.sort = sort
         self.random = random
         self.wrapperfunc = wrapperfunc
+        self.filters = filters
 
+    def __str__(self):
+        return "%s(%s, %s, %s, random=%s)->%s" % (self.__class__.__name__, self.wrapperfunc, self.sort, self.filters,
+                                                  self.random, self.songdbid)
+        
 
 class dbrequestlist(dbrequest):
     """ db request yielding a result list (not containing songs),
@@ -83,30 +88,29 @@ class dbrequestlist(dbrequest):
 
     Note that the resulting list must not be changed by the caller!
     """
-    def __init__(self, songdbid, wrapperfunc=None, sort=False):
+    def __init__(self, songdbid, wrapperfunc=None, sort=False, filters=None):
         self.songdbid = songdbid
         self.wrapperfunc = wrapperfunc
         self.sort = sort
+        self.filters = filters
 
     def __str__(self):
-        return "%s(%s, %s)->%s" % (self.__class__.__name__, self.wrapperfunc, self.sort, self.songdbid)
-
+        return "%s(%s, %s, %s)->%s" % (self.__class__.__name__, self.wrapperfunc, self.sort, self.filters, self.songdbid)
 
 #
 # database requests which yield a single result
 #
 
-class getdatabaseinfo(dbrequestsingle):
-    # XXX make this a db request. Like this it's bogus.
-    """ return tuple (type, location) of database """
+class getdatabasestats(dbrequest):
+    """ return songdbstats instance for database """
     pass
-        
+
 
 class queryregistersong(dbrequestsingle):
     def __init__(self, songdbid, path):
         self.songdbid = songdbid
         self.path = path
-        
+
     def __str__(self):
         return "%s(%s)->%s" % (self.__class__.__name__, self.path, self.songdbid)
 
@@ -115,7 +119,7 @@ class getsong(dbrequestsingle):
     def __init__(self, songdbid, id):
         self.songdbid = songdbid
         self.id = id
-        
+
     def __str__(self):
         return "%s(%s)->%s" % (self.__class__.__name__, self.id, self.songdbid)
 
@@ -124,7 +128,7 @@ class getalbum(dbrequestsingle):
     def __init__(self, songdbid, album):
         self.songdbid = songdbid
         self.album = album
-        
+
     def __str__(self):
         return "%s(%s)->%s" % (self.__class__.__name__, self.album, self.songdbid)
 
@@ -133,7 +137,7 @@ class getartist(dbrequestsingle):
     def __init__(self, songdbid, artist):
         self.songdbid = songdbid
         self.artist = artist
-        
+
     def __str__(self):
         return "%s(%s)->%s" % (self.__class__.__name__, self.artist, self.songdbid)
 
@@ -142,7 +146,7 @@ class getplaylist(dbrequestsingle):
     def __init__(self, songdbid, path):
         self.songdbid = songdbid
         self.path = path
-        
+
     def __str__(self):
         return "%s(%s)->%s" % (self.__class__.__name__, self.path, self.songdbid)
 
@@ -158,30 +162,22 @@ class getsongsinplaylist(dbrequestsingle):
         return "%s(%s,random=%s)->%s" % (self.__class__.__name__,
                                          self.path, self.random, self.songdbid)
 
-
 #
 # database requests which yield a list of songs
 #
 
 class getsongs(dbrequestsongs):
-    
-    def __init__(self, songdbid, artist=None, album=None, indexname=None, indexid=None,
-                 random=False, sort=False):
+
+    def __init__(self, songdbid, artist=None, album=None, sort=False, filters=None, random=False):
         dbrequestsongs.__init__(self, songdbid, random, sort)
         self.songdbid = songdbid
         self.artist = artist
         self.album = album
-        self.indexname = indexname
-        self.indexid = indexid
-        
+        self.filters = filters
+
     def __str__(self):
-        return ( "%s(%s, %s, (%s->%s), random=%s, sort=%s)->%s" %
-                 (self.__class__.__name__,
-                  self.artist, self.album,
-                  self.indexname, self.indexid,
-                  self.random,
-                  self.sort,
-                  self.songdbid))
+        return "%s(%s, %s, sort=%s, filters=%s, random=%s)->%s" % (self.__class__.__name__,
+                  self.artist, self.album, self.sort,  self.filters, self.random, self.songdbid)
 
 
 class getlastplayedsongs(dbrequestsongs):
@@ -192,8 +188,8 @@ class getlastplayedsongs(dbrequestsongs):
         song, playingtime = playingtimesongtuple
         return item.song(songdbid, song, playingtime)
 
-    def __init__(self, songdbid, random=False, sort=False, wrapperfunc=_songwrapper):
-        dbrequestsongs.__init__(self, songdbid, random, sort, wrapperfunc)
+    def __init__(self, songdbid, random=False, sort=False, wrapperfunc=_songwrapper, filters=None):
+        dbrequestsongs.__init__(self, songdbid, random, sort, wrapperfunc, filters)
 
 
 class gettopplayedsongs(dbrequestsongs):
@@ -210,41 +206,35 @@ class getsongsinplaylists(dbrequestsongs):
 
 
 class getartists(dbrequestlist):
-    def __init__(self, songdbid, indexname=None, indexid=None, wrapperfunc=None, sort=False):
+    def __init__(self, songdbid, wrapperfunc=None, sort=False, filters=None):
         self.songdbid = songdbid
-        self.indexname = indexname
-        self.indexid = indexid
         self.wrapperfunc = wrapperfunc
         self.sort = sort
-        
+        self.filters = filters
+
     def __str__(self):
-        return "%s(%s, %s), %s, %s )->%s" % (self.__class__.__name__,
-                                             self.indexname, self.indexid, self.wrapperfunc, self.sort, self.songdbid)
-    
+        return "%s(%s, %s, %s)->%s" % (self.__class__.__name__,
+                                       self.wrapperfunc, self.sort, self.filters, self.songdbid)
+
 
 class getalbums(dbrequestlist):
-    def __init__(self, songdbid, artist=None, indexname=None, indexid=None, wrapperfunc=None, sort=False):
+    def __init__(self, songdbid, artist=None, wrapperfunc=None, sort=False, filters=None):
         self.songdbid = songdbid
         self.artist = artist
-        self.indexname = indexname
-        self.indexid = indexid
         self.wrapperfunc = wrapperfunc
         self.sort = sort
-        
+        self.filters = filters
+
     def __str__(self):
-        return "%s(%s, %s, %s, %s %s)->%s" % (self.__class__.__name__,
-                                              self.artist, self.indexname, self.indexid, self.wrapperfunc, self.sort,
-                                              self.songdbid)
+        return "%s(%s, %s, %s, %s)->%s" % (self.__class__.__name__,
+                                           self.artist, self.wrapperfunc, self.sort, self.filters,
+                                           self.songdbid)
 
 
 class getgenres(dbrequestlist):
     pass
 
 
-class getyears(dbrequestlist):
-    pass
-
-
 class getdecades(dbrequestlist):
     pass
 
@@ -261,30 +251,49 @@ class getplaylists(dbrequestlist):
 #
 
 class getnumberofsongs(dbrequest):
-    def __init__(self, songdbid, artist=None, album=None, indexname=None, indexid=None):
+    def __init__(self, songdbid, artist=None, album=None, filters=None):
         self.songdbid = songdbid
         self.artist = artist
         self.album = album
-        self.indexname = indexname
-        self.indexid = indexid
-        
+        self.filters = filters
+
     def __str__(self):
-        return ( "%s(%s, %s, (%s->%s))->%s" %
+        return ( "%s(%s, %s, %s))->%s" %
                  (self.__class__.__name__,
-                  self.artist, self.album,
-                  self.indexname, self.indexid,
+                  self.artist, self.album, self.filters,
                   self.songdbid))
 
-class getnumberofalbums(dbrequest):
+
+class dbrequestnumber(dbrequest):
+    def __init__(self, songdbid, filters=None):
+        self.songdbid = songdbid
+        self.filters = filters
+
+    def __str__(self):
+        return ( "%s(%s))->%s" % (self.__class__.__name__, self.filters, self.songdbid))
+
+
+class getnumberofalbums(dbrequestnumber):
     pass
 
-class getnumberofdecades(dbrequest):
+class getnumberofartists(dbrequestnumber):
     pass
 
-class getnumberofgenres(dbrequest):
+class getnumberofdecades(dbrequestnumber):
     pass
 
-class getnumberofratings(dbrequest):
+class getnumberofgenres(dbrequestnumber):
+    pass
+
+class getnumberofratings(dbrequestnumber):
+    pass
+
+# songdbmanager
+
+class getsongdbmanagerstats(request):
+    """ request statistical information about songdbs and the request cache
+
+    Returns services.songdb.songdbmanagerstats instance."""
     pass
 
 #
