@@ -17,7 +17,7 @@
 # along with PyTone; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import copy, math, random, service, time
+import copy, gc, math, random, service, time
 import config
 import events, hub, requests
 import dbitem, item, log
@@ -84,6 +84,20 @@ def _genrandomchoice(songs):
         sample = [song for song in sample if song not in result]
     return result
 
+#
+# a collection of statistical information
+#
+
+class songdbmanagerstats:
+    def __init__(self, songdbsstats, requestcachesize, requestcachemaxsize,
+                 requestcacherequests, requestcachehits, requestcachemisses):
+        self.songdbsstats = songdbsstats
+        self.requestcachesize = requestcachesize
+        self.requestcachemaxsize = requestcachemaxsize
+        self.requestcacherequests = requestcacherequests
+        self.requestcachehits = requestcachehits
+        self.requestcachemisses = requestcachemisses
+
 #
 # the song database manager class
 #
@@ -110,19 +124,23 @@ class songdbmanager(service.service):
         self.songdbids = []
 
         # result cache containing a mapping hash(request) -> (request, result, lastaccess)
-        self.resultcache = {}
-        # maximal number of items stored in cache
-        self.resultcachesize = 500
+        self.requestcache = {}
+        # maximal number of objects referred by request cache
+        self.requestcachemaxsize = config.database.requestcachesize
         # cache use statististics
-        self.resultcachehits = 0
-        self.resultcachemisses = 0
+        self.requestcachehits = 0
+        self.requestcachemisses = 0
+        # current number of objects referred to by items in result cache
+        self.requestcachesize = 0 
         
         # we are a database service provider...
         self.channel.supply(requests.dbrequestsingle, self.dbrequestsingle)
         self.channel.supply(requests.dbrequestsongs, self.dbrequestsongs)
         self.channel.supply(requests.dbrequestlist, self.dbrequestlist)
+        self.channel.supply(requests.getdatabasestats, self.getdatabasestats)
         self.channel.supply(requests.getnumberofsongs, self.getnumberofsongs)
         self.channel.supply(requests.getnumberofalbums, self.getnumberofalbums)
+        self.channel.supply(requests.getnumberofartists, self.getnumberofartists)
         self.channel.supply(requests.getnumberofdecades, self.getnumberofdecades)
         self.channel.supply(requests.getnumberofgenres, self.getnumberofgenres)
         self.channel.supply(requests.getnumberofratings, self.getnumberofratings)
@@ -130,9 +148,12 @@ class songdbmanager(service.service):
         # and need to be informed about database changes
         self.channel.subscribe(events.dbevent, self.dbevent)
 
+        # finally, we supply some information about the databases and the cache
+        self.channel.supply(requests.getsongdbmanagerstats, self.getsongdbmanagerstats)
+
     def resetafterexception(self):
         # when an exception occurs, we clear the cache
-        self.resultcache = {}
+        self.requestcache = {}
 
     def addsongdb(self, id, config):
         """ add songdb with id defined by config
@@ -162,31 +183,33 @@ class songdbmanager(service.service):
     def cacheresult(requesthandler):
         """ method decorator which caches results of the request """
         def newrequesthandler(self, request):
-            #if self.resultcachemisses>0:
-            #    log.debug("%3d%% cache hits" % (100.*self.resultcachehits/(self.resultcachehits+self.resultcachemisses)))
             requesthash = hash(request)
             log.debug("dbrequest cache query for request: %s, %d" % (request, requesthash))
             try:
                 # try to get the result from the cache
-                result = self.resultcache[requesthash][0]
+                result = self.requestcache[requesthash][0]
                 # update atime
-                self.resultcache[requesthash][2] = time.time()
-                self.resultcachehits += 1
+                self.requestcache[requesthash][2] = time.time()
+                self.requestcachehits += 1
                 log.debug("dbrequest cache hit for request: %s" % request)
             except KeyError:
                 # make a copy of request for later storage in cache
                 requestcopy = copy.copy(request)
                 result = requesthandler(self, request)
-                self.resultcache[requesthash] = [result, requestcopy, time.time()]
-                self.resultcachemisses += 1
+                resultnoobjects = len(gc.get_referents(result)) + 1
+                self.requestcache[requesthash] = [result, requestcopy, time.time(), resultnoobjects]
+                self.requestcachemisses += 1
+                self.requestcachesize += resultnoobjects
                 # remove least recently used items from cache
-                if len(self.resultcache) > self.resultcachesize:
-                    log.info("db rqeuest cache: purging old items")
-                    cachebytime = [(item[2], key) for key, item in self.resultcache.items()]
+                if self.requestcachesize > self.requestcachemaxsize:
+                    log.debug("db rqeuest cache: purging old items")
+                    cachebytime = [(item[2], key) for key, item in self.requestcache.items()]
                     cachebytime.sort()
                     for atime, key in cachebytime[-10:]:
-                        del self.resultcache[key]
-                log.debug("db request cache miss for request: %s (%d requests cached)" % (request, len(self.resultcache)))
+                        self.requestcachesize -= self.requestcache[key][3]
+                        del self.requestcache[key]
+                log.debug("db request cache miss for request: %s (%d requests and %d objects cached)" %
+                          (request, len(self.requestcache), self.requestcachesize))
             return result
         return newrequesthandler
 
@@ -215,7 +238,7 @@ class songdbmanager(service.service):
     # cache update
 
     def updatecache(self, event):
-        """ update/clear resultcache when database event sent """
+        """ update/clear requestcache when database event sent """
         if isinstance(event, (events.checkpointdb, events.autoregistersongs)):
             return
         if isinstance(event, events.updatesong):
@@ -226,20 +249,20 @@ class songdbmanager(service.service):
             if ( oldsong.album == newsong.album and
                  oldsong.artist == newsong.artist and
                  oldsong.genre == newsong.genre and
-                 oldsong.year == newsong.year and
+                 oldsong.decade == newsong.decade and
                  oldsong.rating == newsong.rating ):
                 # only the playing information was changed, so we just
                 # delete the relevant cache results
 
-                for key, item in self.resultcache.items():
+                for key, item in self.requestcache.items():
                     if isinstance(item[1], (requests.gettopplayedsongs, requests.getlastplayedsongs)):
-                        del self.resultcache[key]
+                        del self.requestcache[key]
                 return
         # otherwise we delete the queries for the correponding database (and all compound queries)
-        for key, item in self.resultcache.items():
+        for key, item in self.requestcache.items():
             songdbid = item[1].songdbid
             if songdbid is None or songdbid == event.songdbid:
-                del self.resultcache[key]
+                del self.requestcache[key]
 
     # event handlers
 
@@ -349,35 +372,40 @@ class songdbmanager(service.service):
                 return result
     dbrequestlist = cacheresult(sortresult(dbrequestlist))
 
+    def getdatabasestats(self, request):
+        if request.songdbid is None:
+            return "Virtual", ""
+        elif request.songdbid not in self.songdbids:
+            log.error("songdbmanager: invalid songdbid '%s' for database request" % request.songdbid)
+        else:
+            return self.songdbhub.request(request)
+
     # requests which return number of items of a certain kind
 
-    def _requestnumbers(self, request, listrequest, requestkwargs={}):
+    def getnumberofsongs(self, request):
+        if request.songdbid is not None and request.songdbid not in self.songdbids:
+            log.error("songdbmanager: invalid songdbid '%s' for database request" % request.songdbid)
+        if request.songdbid is not None and request.artist is request.album is None and not request.filters:
+            return self.songdbhub.request(request)
+        else:
+            return len(self.dbrequestsongs(requests.getsongs(songdbid=request.songdbid,
+                                                             artist=request.artist, album=request.album,
+                                                             filters=request.filters)))
+    getnumberofsongs = cacheresult(getnumberofsongs)
+
+    def _requestnumbers(self, request, listrequest):
         """ helper method for a request which queries for the number of items.
-        
+
         If a database is specified, the corresponding database request is
         executed directly. Otherwise, the length of the result of listrequest
         is returned. """
         if request.songdbid is not None and request.songdbid not in self.songdbids:
             log.error("songdbmanager: invalid songdbid '%s' for database request" % request.songdbid)
-        elif request.songdbid is None or requestkwargs:
-            if issubclass(listrequest, requests.dbrequestlist):
-                return len(self.dbrequestlist(listrequest(songdbid=None, **requestkwargs)))
-            else:
-                return len(self.dbrequestsongs(listrequest(songdbid=None, **requestkwargs)))
+        elif request.songdbid is None or request.filters:
+            return len(self.dbrequestlist(listrequest(songdbid=request.songdbid, filters=request.filters)))
         else:
             return self.songdbhub.request(request)
 
-    def getnumberofsongs(self, request):
-        if request.artist is request.album is request.indexname is request.indexid is None:
-            requestkwargs = {}
-        else:
-            requestkwargs = { "artist": request.artist,
-                              "album": request.album,
-                              "indexname": request.indexname,
-                              "indexid": request.indexid }
-        return self._requestnumbers(request, requests.getsongs, requestkwargs)
-    getnumberofsongs = cacheresult(getnumberofsongs)
-
     def getnumberofalbums(self, request):
         return self._requestnumbers(request, requests.getalbums)
     getnumberofalbums = cacheresult(getnumberofalbums)
@@ -386,6 +414,10 @@ class songdbmanager(service.service):
         return self._requestnumbers(request, requests.getdecades)
     getnumberofdecades = cacheresult(getnumberofdecades)
 
+    def getnumberofartists(self, request):
+        return self._requestnumbers(request, requests.getartists)
+    getnumberofartists = cacheresult(getnumberofartists)
+
     def getnumberofgenres(self, request):
         return self._requestnumbers(request, requests.getgenres)
     getnumberofgenres = cacheresult(getnumberofgenres)
@@ -393,4 +425,13 @@ class songdbmanager(service.service):
     def getnumberofratings(self, request):
         return self._requestnumbers(request, requests.getratings)
     getnumberofratings = cacheresult(getnumberofratings)
+
+    def getsongdbmanagerstats(self, request):
+        songdbsstats = []
+        for songdbid in self.songdbids:
+            songdbsstats.append(self.songdbhub.request(requests.getdatabasestats(songdbid)))
+        return songdbmanagerstats(songdbsstats,
+                                  self.requestcachesize, self.requestcachemaxsize,
+                                  len(self.requestcache),
+                                  self.requestcachehits, self.requestcachemisses)
         
