@@ -102,7 +102,7 @@ class window:
 
     def clear(self):
         for y in range(self.ih):
-            self.win.addstr(y+1, self.ix, " "*self.iw)
+            self.addstr(y+1, self.ix, " "*self.iw)
 
     def hline(self, x, y, c, n, attr):
         try:
